.. Please when editing this file make sure to keep it matching the
   docs in ../configuration.rst:reference_to_examples

sphinx_gallery.gen_gallery
==========================

.. automodule:: sphinx_gallery.gen_gallery

   
   

   Functions
   ---------

   

   .. autofunction:: check_duplicate_filenames

   .. include:: backreferences/sphinx_gallery.gen_gallery.check_duplicate_filenames.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: check_spaces_in_filenames

   .. include:: backreferences/sphinx_gallery.gen_gallery.check_spaces_in_filenames.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: collect_gallery_files

   .. include:: backreferences/sphinx_gallery.gen_gallery.collect_gallery_files.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: cost_name_key

   .. include:: backreferences/sphinx_gallery.gen_gallery.cost_name_key.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: generate_gallery_rst

   .. include:: backreferences/sphinx_gallery.gen_gallery.generate_gallery_rst.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: get_default_config_value

   .. include:: backreferences/sphinx_gallery.gen_gallery.get_default_config_value.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: get_subsections

   .. include:: backreferences/sphinx_gallery.gen_gallery.get_subsections.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: parse_config

   .. include:: backreferences/sphinx_gallery.gen_gallery.parse_config.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: setup

   .. include:: backreferences/sphinx_gallery.gen_gallery.setup.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: setup_module

   .. include:: backreferences/sphinx_gallery.gen_gallery.setup_module.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: summarize_failing_examples

   .. include:: backreferences/sphinx_gallery.gen_gallery.summarize_failing_examples.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: touch_empty_backreferences

   .. include:: backreferences/sphinx_gallery.gen_gallery.touch_empty_backreferences.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: write_computation_times

   .. include:: backreferences/sphinx_gallery.gen_gallery.write_computation_times.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>

   .. autofunction:: write_junit_xml

   .. include:: backreferences/sphinx_gallery.gen_gallery.write_junit_xml.examples

   .. raw:: html

	       <div class="sphx-glr-clear"></div>
   
   

   
   
   

   
   
   